'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof2 = require('babel-runtime/helpers/typeof');

var _typeof3 = _interopRequireDefault(_typeof2);

exports.randomString = randomString;
exports.randomNumber = randomNumber;

var _crypto = require('crypto');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function randomString() {
  var size = arguments.length <= 0 || arguments[0] === undefined ? 10 : arguments[0];
  var charset = arguments[1];

  if (size <= 0) {
    throw new Error('random size must be above 0!');
  }

  if (typeof size !== 'number') {
    throw new TypeError('expected number, got ' + (typeof size === 'undefined' ? 'undefined' : (0, _typeof3.default)(size)));
  }

  var bytes = (0, _crypto.randomBytes)(size);
  var chars = charset || 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789';

  var value = '';
  for (var i = 0, len = bytes.length; i < len; i++) {
    value += chars[bytes.readUInt8(i) % chars.length];
  }

  return value;
}

function randomNumber() {
  var options = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];

  var integerLimit = Number.MAX_SAFE_INTEGER;

  options.min = options.min || 0;
  options.max = options.max || integerLimit;

  if (typeof options.min !== 'number' || typeof options.max !== 'number') {
    throw new TypeError('min and max have to be numbers');
  }

  if (options.min < 0 || options.min > integerLimit - 1 || options.max < 1 || options.max > integerLimit) {
    throw new Error('limits must be between 0 and ' + integerLimit);
  }

  var hex = (0, _crypto.randomBytes)(16).toString('hex');
  var integer = parseInt(hex, 16);
  var random = integer / 0xffffffffffffffffffffffffffffffff;

  return Math.floor(random * (options.max - options.min + 1) + options.min);
}